@@ -37,7 +37,11 @@ public:
 protected:
     QList<QWidget *> createItemWidgets(const QModelIndex &index) const override;
 
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     void updateItemWidgets(const QList<QWidget *> widgets, const QStyleOptionViewItem &option, const QPersistentModelIndex & /*index*/) const override;
+#else
+    void updateItemWidgets(const QList<QWidget *> &widgets, const QStyleOptionViewItem &option, const QPersistentModelIndex & /*index*/) const override;
+#endif
 
     void paint(QPainter *painter, const QStyleOptionViewItem &option, const QModelIndex &index) const override;
 
