@@ -29,6 +29,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 #include <KIO/MkdirJob>
 #include <KIO/StatJob>
 #include <KJobWidgets>
+#include <kio_version.h>
 
 QUrl setUpRemoteTestDir(const QString &testFile)
 {
@@ -42,7 +43,11 @@ QUrl setUpRemoteTestDir(const QString &testFile)
     baseUrl = baseUrl.adjusted(QUrl::StripTrailingSlash);
     baseUrl.setPath(baseUrl.path() + "/gwenview-remote-tests");
 
+#if KIO_VERSION >= QT_VERSION_CHECK(5, 240, 0)
+    auto statJob = KIO::stat(baseUrl, KIO::StatJob::DestinationSide, KIO::StatNoDetails);
+#else
     auto statJob = KIO::statDetails(baseUrl, KIO::StatJob::DestinationSide, KIO::StatNoDetails);
+#endif
     KJobWidgets::setWindow(statJob, authWindow);
 
     if (statJob->exec()) {
@@ -187,3 +192,5 @@ void TimedEventLoop::fail()
 }
 
 } // namespace TestUtils
+
+#include "moc_testutils.cpp"
